AppleClientSecretPayload

Struct AppleClientSecretPayload 

pub struct AppleClientSecretPayload { /* private fields */ }
https://developer.apple.com/documentation/sign_in_with_apple/generate_and_validate_tokens

In order to eliminate the security related isssue, this library does not require plain private key. It is your responsibility to create openssl::ec::EcKey. Please see its document. In most case, you only need to use openssl::ec::EcKey::private_key_from_pem and PKey::from_ec_key. See the following code. Or just use create_pkey.

let pkey = openssl::pkey::PKey::from_ec_key(
	openssl::ec::EcKey::private_key_from_pem(b"your private auth key").unwrap(),
).unwrap();

Implementations

Source

impl AppleClientSecretPayload

pub fn new( team_id: String, client_id: String, issued_at: Option<u64>, valid_while: Option<Duration>, key_id: String, pkey: Option<PKey<Private>>, ) -> Result<Self>

  • team_id: From developers account
  • client_id: Your bundle id or web client id
  • issued_at: iat. Default now.
  • valid_while: Max 6 months.
  • key_id: From your pem generation
  • pkey: From your pem
pub fn encode(&self) -> Result<String>

Encode client secret into JWT string